/****************************************************************************
** Meta object code from reading C++ file 'tripgroupmapmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../itinerary-26.04.0/src/app/tripgroupmapmodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tripgroupmapmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12MapPathEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto MapPathEntry::qt_create_metaobjectdata<qt_meta_tag_ZN12MapPathEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MapPathEntry",
        "journeySection",
        "KPublicTransport::JourneySection",
        "color",
        "QColor",
        "textColor",
        "width",
        "showStart",
        "showEnd"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'journeySection'
        QtMocHelpers::PropertyData<KPublicTransport::JourneySection>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(5, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'width'
        QtMocHelpers::PropertyData<double>(6, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showStart'
        QtMocHelpers::PropertyData<bool>(7, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showEnd'
        QtMocHelpers::PropertyData<bool>(8, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MapPathEntry, qt_meta_tag_ZN12MapPathEntryE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MapPathEntry::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MapPathEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MapPathEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12MapPathEntryE_t>.metaTypes,
    nullptr
} };

void MapPathEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<MapPathEntry *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::JourneySection >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::JourneySection*>(_v) = _t->journeySection; break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->color; break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->textColor; break;
        case 3: *reinterpret_cast<double*>(_v) = _t->width; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->showStart; break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->showEnd; break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN13MapPointEntryE_t {};
} // unnamed namespace

template <> constexpr inline auto MapPointEntry::qt_create_metaobjectdata<qt_meta_tag_ZN13MapPointEntryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MapPointEntry",
        "location",
        "KPublicTransport::Location",
        "color",
        "QColor",
        "textColor",
        "iconName"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'location'
        QtMocHelpers::PropertyData<KPublicTransport::Location>(1, 0x80000000 | 2, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'color'
        QtMocHelpers::PropertyData<QColor>(3, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'textColor'
        QtMocHelpers::PropertyData<QColor>(5, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MapPointEntry, qt_meta_tag_ZN13MapPointEntryE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MapPointEntry::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MapPointEntryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13MapPointEntryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13MapPointEntryE_t>.metaTypes,
    nullptr
} };

void MapPointEntry::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<MapPointEntry *>(_o);
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KPublicTransport::Location >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KPublicTransport::Location*>(_v) = _t->location; break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->color; break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->textColor; break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->iconName; break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN17TripGroupMapModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TripGroupMapModel::qt_create_metaobjectdata<qt_meta_tag_ZN17TripGroupMapModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TripGroupMapModel",
        "QML.Element",
        "auto",
        "tripGroupIdChanged",
        "",
        "contentChanged",
        "setupChanged",
        "tripGroupId",
        "tripGroupManager",
        "TripGroupManager*",
        "liveDataManager",
        "LiveDataManager*",
        "transferManager",
        "TransferManager*",
        "journeySections",
        "QList<MapPathEntry>",
        "points",
        "QList<MapPointEntry>",
        "boundingBox",
        "QRectF"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'tripGroupIdChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'contentChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setupChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'tripGroupId'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Final, 0),
        // property 'tripGroupManager'
        QtMocHelpers::PropertyData<TripGroupManager*>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'liveDataManager'
        QtMocHelpers::PropertyData<LiveDataManager*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'transferManager'
        QtMocHelpers::PropertyData<TransferManager*>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 2),
        // property 'journeySections'
        QtMocHelpers::PropertyData<QList<MapPathEntry>>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'points'
        QtMocHelpers::PropertyData<QList<MapPointEntry>>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'boundingBox'
        QtMocHelpers::PropertyData<QRectF>(18, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TripGroupMapModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TripGroupMapModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TripGroupMapModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TripGroupMapModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17TripGroupMapModelE_t>.metaTypes,
    nullptr
} };

void TripGroupMapModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TripGroupMapModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->tripGroupIdChanged(); break;
        case 1: _t->contentChanged(); break;
        case 2: _t->setupChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TripGroupMapModel::*)()>(_a, &TripGroupMapModel::tripGroupIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupMapModel::*)()>(_a, &TripGroupMapModel::contentChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TripGroupMapModel::*)()>(_a, &TripGroupMapModel::setupChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< LiveDataManager* >(); break;
        case 3:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TransferManager* >(); break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TripGroupManager* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_tripGroupId; break;
        case 1: *reinterpret_cast<TripGroupManager**>(_v) = _t->m_tripGroupMgr; break;
        case 2: *reinterpret_cast<LiveDataManager**>(_v) = _t->m_liveDataMgr; break;
        case 3: *reinterpret_cast<TransferManager**>(_v) = _t->m_transferMgr; break;
        case 4: *reinterpret_cast<QList<MapPathEntry>*>(_v) = _t->journeySections(); break;
        case 5: *reinterpret_cast<QList<MapPointEntry>*>(_v) = _t->points(); break;
        case 6: *reinterpret_cast<QRectF*>(_v) = _t->boundingBox(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_tripGroupId, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->tripGroupIdChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_tripGroupMgr, *reinterpret_cast<TripGroupManager**>(_v)))
                Q_EMIT _t->setupChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_liveDataMgr, *reinterpret_cast<LiveDataManager**>(_v)))
                Q_EMIT _t->setupChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_transferMgr, *reinterpret_cast<TransferManager**>(_v)))
                Q_EMIT _t->setupChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *TripGroupMapModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TripGroupMapModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TripGroupMapModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int TripGroupMapModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void TripGroupMapModel::tripGroupIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TripGroupMapModel::contentChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TripGroupMapModel::setupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
